@@ -1,23 +1,17 @@
 package OODoc::Format::Pod;
 use vars '$VERSION';
-$VERSION = '0.97';
+$VERSION = '0.98';
 use base 'OODoc::Format';
 
 use strict;
 use warnings;
 
-use Carp;
-use File::Spec;
+use File::Spec   ();
+use Carp         qw/confess/;
 use List::Util   qw/max/;
 use Pod::Escapes qw/e2char/;
 
 
-#-------------------------------------------
-
-
-#-------------------------------------------
-
-
 sub link($$;$)
 {   my ($self, $manual, $object, $text) = @_;
     $object = $object->subroutine if $object->isa('OODoc::Text::Option');
@@ -34,8 +28,6 @@ sub link($$;$)
     : confess "cannot link to a ".ref $object;
 }
 
-#-------------------------------------------
-
 
 sub createManual($@)
 {   my ($self, %args) = @_;
@@ -44,13 +36,15 @@ sub createManual($@)
     my $options  = $args{format_options} || [];
 
     print $manual->orderedChapters." chapters in $manual\n" if $verbose>=3;
-    (my $podname = $manual->source) =~ s/\.pm$/.pod/;
+    my $podname  = my $tmpname = $manual->source;
+    $podname     =~ s/\.pm$/.pod/;
+    $tmpname     =~ s/\.pm$/.tmp/;
 
+    my $tmpfile  = File::Spec->catfile($self->workdir, $tmpname);
     my $podfile  = File::Spec->catfile($self->workdir, $podname);
-    $self->manifest->add($podfile);
 
-    my $output  = IO::File->new($podfile, "w")
-        or die "ERROR: cannot write pod manual at $podfile: $!";
+    my $output  = IO::File->new($tmpfile, "w")
+        or die "ERROR: cannot write prelimary pod manual to $tmpfile: $!";
 
     $self->formatManual
       ( manual => $manual
@@ -59,11 +53,13 @@ sub createManual($@)
       , @$options
       );
 
+    $output->close;
+    $self->cleanupPOD($tmpfile, $podfile);
+    $self->manifest->add($podfile);
+
     $self;
 }
 
-#-------------------------------------------
-
 
 sub formatManual(@)
 {   my $self = shift;
@@ -82,8 +78,6 @@ sub formatManual(@)
     $self;
 }
 
-#-------------------------------------------
-
 sub showAppend(@)
 {   my ($self, %args) = @_;
     my $append = $args{append};
@@ -98,8 +92,6 @@ sub showAppend(@)
     $self;
 }
 
-#-------------------------------------------
-
 sub showStructureExpand(@)
 {   my ($self, %args) = @_;
 
@@ -121,8 +113,6 @@ sub showStructureExpand(@)
     return $self;
 }
 
-#-------------------------------------------
-
 sub showStructureRefer(@)
 {   my ($self, %args) = @_;
 
@@ -138,8 +128,6 @@ sub showStructureRefer(@)
     $self;
 }
 
-#-------------------------------------------
-
 sub chapterDescription(@)
 {   my ($self, %args) = @_;
 
@@ -155,8 +143,6 @@ sub chapterDescription(@)
     $self->showChapterIndex($output, $details, "   ");
 }
 
-#-------------------------------------------
-
 sub chapterDiagnostics(@)
 {   my ($self, %args) = @_;
 
@@ -178,8 +164,6 @@ sub chapterDiagnostics(@)
     $self;
 }
 
-#-------------------------------------------
-
 
 sub showChapterIndex($$;$)
 {   my ($self, $output, $chapter, $indent) = @_;
@@ -194,8 +178,6 @@ sub showChapterIndex($$;$)
     $self;
 }
 
-#-------------------------------------------
-
 sub showExamples(@)
 {   my ($self, %args) = @_;
     my $examples = $args{examples} or confess;
@@ -212,8 +194,6 @@ sub showExamples(@)
     $self;
 }
 
-#-------------------------------------------
-
 sub showDiagnostics(@)
 {   my ($self, %args) = @_;
     my $diagnostics = $args{diagnostics} or confess;
@@ -231,8 +211,6 @@ sub showDiagnostics(@)
     $self;
 }
 
-#-------------------------------------------
-
 
 sub chapterInheritance(@)
 {   my ($self, %args) = @_;
@@ -293,8 +271,6 @@ sub showSuperSupers($$)
     $self;
 }
 
-#-------------------------------------------
-
 sub showSubroutine(@)
 {   my $self = shift;
     $self->SUPER::showSubroutine(@_);
@@ -305,8 +281,6 @@ sub showSubroutine(@)
     $self;
 }
 
-#-------------------------------------------
-
 sub showSubroutineUse(@)
 {   my ($self, %args) = @_;
     my $subroutine = $args{subroutine} or confess;
@@ -340,8 +314,6 @@ sub showSubroutineUse(@)
     $self;
 }
 
-#-------------------------------------------
-
 sub showSubroutineName(@)
 {   my ($self, %args) = @_;
     my $subroutine = $args{subroutine} or confess;
@@ -360,8 +332,6 @@ sub showSubroutineName(@)
      );
 }
 
-#-------------------------------------------
-
 sub showOptionUse(@)
 {   my ($self, %args) = @_;
     my $output = $args{output} or confess;
@@ -376,8 +346,6 @@ sub showOptionUse(@)
     $self;
 }
 
-#-------------------------------------------
-
 sub showOptionExpand(@)
 {   my ($self, %args) = @_;
     my $output = $args{output} or confess;
@@ -394,8 +362,6 @@ sub showOptionExpand(@)
     $self;
 }
 
-#-------------------------------------------
-
 
 sub writeTable($@)
 {   my ($self, %args) = @_;
@@ -437,8 +403,6 @@ sub writeTable($@)
        for @rows;
 }
 
-#-------------------------------------------
-
 
 sub removeMarkup($)
 {   my ($self, $string) = @_;
@@ -508,8 +472,6 @@ sub _removeMarkup($)
     $out . $string;
 }
 
-#-------------------------------------------
-
 sub showSubroutineDescription(@)
 {   my ($self, %args) = @_;
     my $manual  = $args{manual}                   or confess;
@@ -526,8 +488,6 @@ sub showSubroutineDescription(@)
     $self->showSubroutineDescriptionRefer(%args, subroutine => $refer);
 }
 
-#-------------------------------------------
-
 sub showSubroutineDescriptionRefer(@)
 {   my ($self, %args) = @_;
     my $manual  = $args{manual}                   or confess;
@@ -536,11 +496,37 @@ sub showSubroutineDescriptionRefer(@)
     $output->print("\nSee ", $self->link($manual, $subroutine), "\n");
 }
 
-#-------------------------------------------
-
 sub showSubsIndex() {;}
 
-#-------------------------------------------
+
+sub cleanupPOD($$)
+{   my ($self, $infn, $outfn) = @_;
+    my $in = IO::File->new($infn, 'r')
+        or die "ERROR: cannot read prelimary pod from $infn: $!\n";
+
+    my $out = IO::File->new($outfn, 'w')
+        or die "ERROR: cannot write final pod to $outfn: $!\n";
+
+    my $last_is_blank = 1;
+  LINE:
+    while(my $l = $in->getline)
+    {   if($l =~ m/^\s*$/s)
+        {    next LINE if $last_is_blank;
+             $last_is_blank = 1;
+        }
+        else
+        {    $last_is_blank = 0;
+        }
+
+        $out->print($l);
+    }
+
+    $in->close;
+    $out->close
+       or die "ERROR: write to $outfn failed: $!\n";
+
+    $self;
+}
 
 
 1;
